@@ -11,6 +11,7 @@ use BackedEnum;
 use DateTimeImmutable;
 use DateTimeInterface;
 use Exception;
+use Money\Money;
 use UnitEnum;
 
 trait hasCasts
@@ -41,6 +42,10 @@ trait hasCasts
             }
 
             if (is_a($cast, BackedEnum::class, true)) {
+                if (method_exists($cast, 'get')) {
+                    return $cast::get($value);
+                }
+
                 /** @var BackedEnum $cast */
                 return $cast::from($value);
             }
@@ -67,6 +72,8 @@ trait hasCasts
 
                         return null;
                     }
+                case Casts::CURRENCY:
+                    return Money::GBP($value);
                 case Casts::SERIALIZE:
                     return unserialize(base64_decode($value));
                 default:
@@ -163,9 +170,17 @@ trait hasCasts
                             $value = $value->getTimestamp();
                         }
                         break;
+                    case Casts::CURRENCY:
+                        if ($value instanceof Money) {
+                            $value = $value->getAmount();
+                        }
+                        break;
                     case Casts::SERIALIZE:
                         $value = base64_encode(serialize($value));
                         break;
+                    case Casts::BOOL:
+                        $value = $value ? 1 : 0;
+                        break;
                     default:
                         break;
                 }
